# NixOps configuration for dionach
{
  config,
  pkgs,
  ...
}: {
  imports = [
    ../../hardware/purism_librem_15.nix # Include results of the hardware scan.
    ../../profiles/desktop_common.nix
    ../../profiles/steam.nix
  ];

  # Use the GRUB 2 boot loader.
  boot = {
    loader.grub = {
      enable = true;
      device = "/dev/nvme0n1"; # or "nodev" for efi only
      useOSProber = true;
    };
    kernel.sysctl."net.ipv4.ip_forward" = "1";
    extraModprobeConfig = "options kvm_intel nested=1";
  };

  networking = {
    hostName = "dionach"; # Define your hostname.
    firewall = {
      enable = true;
      checkReversePath = false; # Needed for libvirtd
      allowedTCPPorts = [15000];
    };
  };

  systemd.network.networks.enp0s20f0u4u4i5.ipv6SendRAConfig = {
    EmitDNS = true;
    Managed = true;
    OtherInformation = true;
  };

  services.kbfs.enable = true;

  # This value determines the NixOS release with which your system is to be
  # compatible, in order to avoid breaking some software such as database
  # servers. You should change this only after NixOS release notes say you
  # should.
  system.stateVersion = "23.11"; # Did you read the comment?
}
