{
  self,
  cardano-node,
  colmena,
  cosmicDesktop,
  daedalus,
  nix,
  nixpkgs,
  nixpkgsUnstable,
  ragenix,
  utils,
  ...
} @ inputs:
(utils.lib.eachDefaultSystem (system: let
  deploymentName = "mio-ops";
  pkgs = nixpkgs.legacyPackages."${system}";
  nix_path = "nixpkgs=${nixpkgs}";
in {
  devShell =
    pkgs.callPackage
    ./shell.nix {
      inherit (colmena.packages."${pkgs.system}") colmena;
      inherit (nix.packages."${pkgs.system}") nix;
      inherit (ragenix.packages."${pkgs.system}") ragenix;
      inherit deploymentName;
      inherit nix_path;
    };
}))
// {
  colmena = {
    meta = {
      description = "mio-ops deployment";
      name = "deploymentName";
      nixpkgs = import nixpkgs {
        system = "x86_64-linux";
        overlays = [];
      };
    };
    defaults = {pkgs, ...}: {
      imports = [
        ./modules
        cosmicDesktop.nixosModules.default
      ];
      # make flake inputs accessible in NixOS
      _module.args.inputs = inputs;
      nixpkgs.overlays = [
        (super: self: {
          inherit (nixpkgsUnstable.legacyPackages."${pkgs.system}") toxvpn;
        })
      ];
      profiles.starship.enable = true;
      profiles.toxvpn.enable = false;
    };
    # Comment out deployment line when building the SD Image.
    airgead = {
      imports = [
        hosts/airgead
        cardano-node.nixosModules.cardano-node
        ragenix.nixosModules.default
      ];
      deployment = {
        tags = ["active" "vps"];
        targetHost = "172.105.187.96";
      };
    };
    brighde = {
      imports = [
        hosts/brighde
        ragenix.nixosModules.default
      ];
      deployment = {
        tags = ["active"];
        targetHost = "10.42.0.124";
      };
    };
    ceilidh = {
      imports = [
        hosts/ceilidh
        ragenix.nixosModules.default
      ];
    };
    ceitidh = {
      imports = [
        hosts/ceitidh
        ragenix.nixosModules.default
      ];
      deployment = {
        tags = ["active" "rPi"];
        targetHost = "10.42.0.203";
      };
    };
    cuallaidh = {
      imports = [
        hosts/cuallaidh
        ragenix.nixosModules.default
      ];
      deployment = {
        tags = ["active" "vps"];
        targetHost = "172.105.171.16";
      };
    };
    #dhu = {
    #  imports = [
    #    hosts/dhu
    #    ragenix.nixosModules.default
    #  ];
    #};
    dionach = {
      imports = [
        hosts/dionach
        ragenix.nixosModules.default
      ];
      deployment = {
        tags = ["active"];
        targetHost = "10.42.0.190";
      };
    };
    doilidh = {
      imports = [
        hosts/doilidh
        ragenix.nixosModules.default
      ];
      deployment = {
        tags = ["active" "rPi"];
        targetHost = "10.42.0.204";
      };
    };
    eamhair = {
      imports = [
        hosts/eamhair
        ragenix.nixosModules.default
      ];
      deployment = {
        tags = ["active" "rPi"];
        targetHost = "10.42.0.205";
      };
      services.toxvpn.localip = "10.37.0.205";
    };
    iolear-beag = {
      imports = [
        hosts/iolear-beag
        ragenix.nixosModules.default
      ];
      deployment = {
        tags = ["inactive"];
        targetHost = "10.42.0.127";
      };
    };
    #paidh-uachdar = {
    #  imports = [
    #    hosts/paidh-uachdar
    #    ragenix.nixosModules.default
    #  ];
    #};
    sanganto = {
      imports = [
        hosts/sanganto
        ragenix.nixosModules.default
      ];
      deployment.targetHost = "10.42.0.11";
      roles.desktop.enable = true;
      roles.desktopCraige.enable = true;
      services.toxvpn.localip = "10.37.0.11";
    };
    sercanto = {
      imports = [
        hosts/sercanto
        ragenix.nixosModules.default
      ];
      deployment.targetHost = "10.42.0.180";
      roles.desktop.enable = true;
      roles.desktopCraige.enable = true;
    };
    sithlainnir = {
      imports = [
        hosts/sithlainnir
        ragenix.nixosModules.default
      ];
      deployment = {
        tags = ["inactive"];
        targetHost = "10.42.0.114";
      };
    };
    teintidh = {
      imports = [
        hosts/teintidh
        ragenix.nixosModules.default
      ];
      deployment = {
        tags = ["inactive"];
        targetHost = "10.42.0.127";
      };
    };
  };
}
